local addon, ns = ...

--***********
--Local functions used by addon functions later
--***********
local function PetBarClass()
	local ClassName = UnitClass("Player")
	if ClassName == "Warlock" then
		return true
	elseif ClassName == "Hunter" then
		return true
	elseif ClassName == "Death Knight" then
		return true
	else
		return false
	end
end

--This code is for the black boxes when the bars are unlocked and movable.
local function SetBackground(frame)
	frame:SetBackdrop({
	 bgFile="Interface\\ChatFrame\\ChatFrameBackground",
	 edgeFile="Interface\\ChatFrame\\ChatFrameBackground",
	 tile=true,
	 tileSize=5,
	 edgeSize= 1,
	})
	frame:SetBackdropColor(0,0,0,1)
	frame:SetBackdropBorderColor(0,0,0,1)
end

local function ClearBackground(frame)
	frame:SetBackdrop(nil)
end

--Sets a given frame to be movable
local function MakeDraggable(frame)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", frame.StartMoving)
	frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
end

--Sets a frame to be immovable
local function MakeStatic(frame)
	frame:SetMovable(false)
	frame:EnableMouse(false)
end


--***********
--Addon-local functions that can be used anywhere in the addon
--***********

--This reparents a list of objects (usually buttons in our case).
function ns.MoveElements(ElementList, FrameName)
	for _, v in pairs(ElementList) do
		v:SetParent(FrameName)
	end
end

function ns.HideElements(ElementList)
	for _, v in pairs(ElementList) do
		v:Hide()
	end
end

function ns.ShowElements(ElementList)
	for _, v in pairs(ElementList) do
		v:Show()
	end
end

function ns.PetBarNeeded()
	if PetBarClass() and PetHasActionBar() then
		return true
	else
		return false
	end
end

function ns.StanceBarNeeded()
	local ClassName = UnitClass("Player")
	if ClassName == "Druid" then
		return true
	else
		return false
	end
end

function ns.HideHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(0)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(0)
	end
	if ns.PetBarNeeded() then
		for i = 1, 10 do
			_G["PetActionButton"..i.."HotKey"]:SetAlpha(0)
		end
	end
	if ns.StanceBarNeeded() then
		for i = 1, 6 do
			_G["StanceButton"..i.."HotKey"]:SetAlpha(0)
		end
	end
end

function ns.ShowHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(1)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(1)
	end
	if ns.PetBarNeeded() then
		for i = 1, 10 do
			_G["PetActionButton"..i.."HotKey"]:SetAlpha(1)
		end
	end
	if ns.StanceBarNeeded() then
		for i = 1, 6 do
			_G["StanceButton"..i.."HotKey"]:SetAlpha(1)
		end
	end
end

function ns.UnlockFrame(frame)
	MakeDraggable(frame)
	SetBackground(frame)
end

function ns.LockFrame(frame)
	MakeStatic(frame)
	ClearBackground(frame)
end

--Hides all the buttons when we unlock the bars.
function ns.HideAllButtons()
	for _, v in pairs(ns.MenuButtons) do
		v:Hide()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Hide()
		_G["MultiBarBottomLeftButton"..i]:Hide()
		_G["MultiBarBottomRightButton"..i]:Hide()
	end
	for i = 1, 10 do
		_G["PetActionButton"..i]:Hide()
	end
	for i = 1, 6 do
		_G["StanceButton"..i]:Hide()
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Hide()
	end
	MainMenuBarBackpackButton:Hide()
end

--Shows the buttons again when the bars are locked.
function ns.ShowAllButtons()
	for _, v in pairs(ns.MenuButtons) do
		v:Show()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Show()
		_G["MultiBarBottomLeftButton"..i]:Show()
		_G["MultiBarBottomRightButton"..i]:Show()
	end
	if ns.PetBarNeeded() then
		for i = 1, 10 do
			_G["PetActionButton"..i]:Show()
		end
	end
	if ns.StanceBarNeeded() then
		for i = 1, 6 do
			_G["StanceButton"..i]:Show()
		end
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Show()
	end
	MainMenuBarBackpackButton:Show()
end

function ns.HideArtifactBar()
	ArtifactWatchBar:Hide()
	ArtifactWatchBar:SetAlpha(0)
	ArtifactWatchBar.StatusBar:SetAlpha(0)
	ArtifactWatchBar.OverlayFrame:SetAlpha(0)
end

function ns.ShowArtifactBar()
	ArtifactWatchBar:Show()
	ArtifactWatchBar:SetAlpha(1)
	ArtifactWatchBar.StatusBar:SetAlpha(1)
	ArtifactWatchBar.OverlayFrame:SetAlpha(1)
end

function ns.SaveBarPosition(bar)
	point, relativeTo, relativePoint, xOffset, yOffset = bar:GetPoint()
	s = bar:GetName()
	cfg = ns.cfg[s]
	cfg.point = point
	cfg.xOfs = xOffset
	cfg.yOfs = yOffset
end